/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.stock.crop.actions;

import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.Action;
import nl.cloudfarming.client.crop.model.Classification;
import nl.cloudfarming.client.crop.model.CropDefinition;
import nl.cloudfarming.client.model.AgroURI;
import nl.cloudfarming.client.model.EntityIdGenerator;
import nl.cloudfarming.client.stock.crop.visual.nodes.ClassificationAggregateNode;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

/**
 * Add a new Classification to the active crop in the croplist.
 *
 * @author Gerben Feenstra & Merijn Zengers
 */
@NbBundle.Messages({
    "Add classification action name=Add classification",
    "Add classification action tooltip=Add classification",
    "Classification default name=User created classification"
})
public class AddClassificationAction extends AbstractAction {

    private static final String ADD_CLASSIFICATION_ACTION_TOOLTIP = Bundle.Add_classification_action_tooltip();
    private static final String ADD_CLASSIFICATION_ICON = "nl/cloudfarming/client/stock/crop/classification.png";
    private static final String ADD_CLASSIFICATION_ENABLED = "nl/cloudfarming/client/stock/crop/classification.png";
    private static final String ADD_CLASSIFICATION_DISABLED = "nl/cloudfarming/client/stock/crop/classification.png";
    private Lookup context;

    /**
     * Makes this action for a specific node
     */
    public AddClassificationAction(Lookup context) {
        super(Bundle.Add_classification_action_name());
        this.context = context;
        this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(ADD_CLASSIFICATION_ICON));
        this.putValue(Action.SHORT_DESCRIPTION, ADD_CLASSIFICATION_ACTION_TOOLTIP);
    }

    @Override
    public void setEnabled(boolean doEnable) {
        if (doEnable) {
            this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(ADD_CLASSIFICATION_ENABLED));
        } else {
            this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(ADD_CLASSIFICATION_DISABLED));
        }
        super.setEnabled(doEnable);
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        // Find active crop
        ClassificationAggregateNode node = context.lookup(ClassificationAggregateNode.class);
        CropDefinition activeCropDefinition = node.getParentNode().getLookup().lookup(CropDefinition.class);
        assert activeCropDefinition != null : "Tried to add classification, but parent cropdefinition cannot be found in lookup";

        String source = Bundle.Crop_default_source();
        String name = Bundle.Classification_default_name();
        EntityIdGenerator idGenerator = Lookup.getDefault().lookup(EntityIdGenerator.class);
        String id = source + "/" + idGenerator.generateId(EntityIdGenerator.USER_DEFINED_KEY);
        // Create new classification for the active crop
        Classification classification = new Classification(new AgroURI("OTHER/00000000/CLN/0"), source, name);
        activeCropDefinition.addClassification(classification);

        // determine if ClassificationNode is expanded or not
        // if not expanded: expand it


    }
}
