/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.stock.crop.actions;

import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.Action;
import nl.cloudfarming.client.crop.model.Crop;
import nl.cloudfarming.client.crop.model.CropDefinition;
import nl.cloudfarming.client.model.AgroURI;
import nl.cloudfarming.client.model.EnterpriseIdProvider;
import nl.cloudfarming.client.stock.crop.storage.CropDefinitionStorage;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;

/**
 * Add a new empty cropdefinition to the croplist.
 *
 * @author Gerben Feenstra & Merijn Zengers
 */
@NbBundle.Messages({
    "Add crop action name=Add crop",
    "Crop default source=User created",
    "Crop default name=User created cropdef",
    "Add crop action tooltip=Add crop"
})
public class AddCropDefinitionAction extends AbstractAction {

    private static final String ADD_CROPDEFINITION_ACTION_TOOLTIP = Bundle.Add_crop_action_tooltip();
    private static final String ADD_CROPDEFINITION_ICON = "nl/cloudfarming/client/stock/crop/addcropdefinition.png";

    /**
     * Makes this action for a specific node
     *
     * @param cropDefinitionNode
     */
    public AddCropDefinitionAction() {
        super(Bundle.Add_crop_action_name());
        this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(ADD_CROPDEFINITION_ICON));
        this.putValue(Action.SHORT_DESCRIPTION, ADD_CROPDEFINITION_ACTION_TOOLTIP);
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        String source = Bundle.Crop_default_source();
        String name = Bundle.Crop_default_name();

        EnterpriseIdProvider eip = new AgroURI("AGRONL/00000000/CRP/0");
        Crop crop = new Crop(eip, name);
        
        CropDefinition cropDefinition = new CropDefinition(eip, crop);
        cropDefinition.setSource(source);
        CropDefinitionStorage.getInstance().addCropDefinition(cropDefinition);
    }
}
