/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.stock.crop.actions;

import java.awt.event.ActionEvent;
import java.util.Collection;
import javax.swing.AbstractAction;
import javax.swing.Action;
import nl.cloudfarming.client.crop.model.Classification;
import nl.cloudfarming.client.crop.model.CropDefinition;
import nl.cloudfarming.client.crop.model.Variety;
import nl.cloudfarming.client.stock.crop.storage.CropDefinitionStorage;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

/**
 * Removes selected items in the croplist. Supports Crops, classifications and
 * varieties For classifications and varieties the parent cropdefinition must
 * also be in the lookup.
 *
 * @author Gerben Feenstra & Merijn Zengers
 */
@NbBundle.Messages("Remove_action_name=Remove")
public class RemoveAction extends AbstractAction {

    private static final String REMOVE_ACTION_TOOLTIP = "Remove";//Bundle.toolbar_remove_action_tooltip();
    private String REMOVE_ICON_ENABLED = "nl/cloudfarming/client/stock/crop/enabled_cross.png";
    private String REMOVE_ICON_DISABLED = "nl/cloudfarming/client/stock/crop/disabled_cross.png";
    private Lookup context;

    public RemoveAction(Lookup context) {
        super(Bundle.Remove_action_name());

        this.context = context;
        this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(REMOVE_ICON_DISABLED));
        this.putValue(Action.SHORT_DESCRIPTION, REMOVE_ACTION_TOOLTIP);
    }

    @Override
    public void setEnabled(boolean doEnable) {
        if (doEnable) {
            this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(REMOVE_ICON_ENABLED));
        } else {
            this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(REMOVE_ICON_DISABLED));
        }
        super.setEnabled(doEnable);
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        for (CropDefinition cropDefinition : getSelectedCropDefinitions()) {
            removeSelectedClassifications(cropDefinition);
            removeSelectedVarieties(cropDefinition);
            removeSelectedCropDefinition(cropDefinition);
        }
    }

    private Collection<? extends CropDefinition> getSelectedCropDefinitions() {
        return context.lookupAll(CropDefinition.class);
    }

    private void removeSelectedClassifications(CropDefinition cropDefinition) {
        for (Classification classification : getSelectedClassifications()) {
            cropDefinition.removeClassification(classification);
        }
    }

    private Collection<? extends Classification> getSelectedClassifications() {
        return context.lookupAll(Classification.class);
    }
    
    private void removeSelectedVarieties(CropDefinition cropDefinition) {
        for (Variety variety : getSelectedVarieties()) {
            cropDefinition.removeVariety(variety);
        }
    }

    private Collection<? extends Variety> getSelectedVarieties() {
        return context.lookupAll(Variety.class);
    }
    
    private void removeSelectedCropDefinition(CropDefinition cropDefinition) {
        if(getSelectedClassifications().isEmpty() && getSelectedVarieties().isEmpty()) {
            CropDefinitionStorage.getInstance().removeCropDefinition(cropDefinition);
        }
    }
}
